@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.106';
+our $VERSION = '0.107';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -1681,7 +1681,7 @@ sub _set_operational_status {
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Tue Sep 11 12:52:04 2018 GMT
+# on Thu Sep 27 03:57:54 2018 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1692,7 +1692,7 @@ __PACKAGE__->status( add => 24796, iridium => '-', 'Iridium 4', 'Tumbling' );
 __PACKAGE__->status( add => 24836, iridium => '-', 'Iridium 914', 'Tumbling' );
 __PACKAGE__->status( add => 24837, iridium => 'D', 'Iridium 12', 'Decayed 2018-09-02' );
 __PACKAGE__->status( add => 24838, iridium => 'D', 'Iridium 9', 'Decayed 2003-03-11' );
-__PACKAGE__->status( add => 24839, iridium => '+', 'Iridium 10', '' );
+__PACKAGE__->status( add => 24839, iridium => '-', 'Iridium 10', 'Tumbling' );
 __PACKAGE__->status( add => 24840, iridium => 'D', 'Iridium 13', 'Decayed 2018-04-29' );
 __PACKAGE__->status( add => 24841, iridium => '-', 'Iridium 16', 'Tumbling' );
 __PACKAGE__->status( add => 24842, iridium => '-', 'Iridium 911', 'Tumbling' );
@@ -1722,7 +1722,7 @@ __PACKAGE__->status( add => 24968, iridium => 'D', 'Iridium 37', 'Decayed 2018-0
 __PACKAGE__->status( add => 24969, iridium => 'D', 'Iridium 34', 'Decayed 2018-01-08' );
 __PACKAGE__->status( add => 25039, iridium => 'D', 'Iridium 43', 'Decayed 2018-02-11' );
 __PACKAGE__->status( add => 25040, iridium => 'D', 'Iridium 41', 'Decayed 2018-07-28' );
-__PACKAGE__->status( add => 25041, iridium => '-', 'Iridium 40', 'Tumbling' );
+__PACKAGE__->status( add => 25041, iridium => 'D', 'Iridium 40', 'Decayed 2018-09-23' );
 __PACKAGE__->status( add => 25042, iridium => '-', 'Iridium 39', 'Tumbling' );
 __PACKAGE__->status( add => 25043, iridium => '-', 'Iridium 38', 'Tumbling' );
 __PACKAGE__->status( add => 25077, iridium => '-', 'Iridium 42', 'Tumbling' );
@@ -1735,8 +1735,8 @@ __PACKAGE__->status( add => 25108, iridium => 'D', 'Iridium 49', 'Decayed 2018-0
 __PACKAGE__->status( add => 25169, iridium => '+', 'Iridium 52', '' );
 __PACKAGE__->status( add => 25170, iridium => '-', 'Iridium 56', 'Tumbling' );
 __PACKAGE__->status( add => 25171, iridium => '+', 'Iridium 54', '' );
-__PACKAGE__->status( add => 25172, iridium => '-', 'Iridium 50', 'Tumbling' );
-__PACKAGE__->status( add => 25173, iridium => '+', 'Iridium 53', '' );
+__PACKAGE__->status( add => 25172, iridium => 'D', 'Iridium 50', 'Decayed 2018-09-23' );
+__PACKAGE__->status( add => 25173, iridium => '-', 'Iridium 53', 'Tumbling' );
 __PACKAGE__->status( add => 25262, iridium => '-', 'Iridium 51', 'Tumbling' );
 __PACKAGE__->status( add => 25263, iridium => 'S', 'Iridium 61', '' );
 __PACKAGE__->status( add => 25272, iridium => 'S', 'Iridium 55', '' );
@@ -1753,7 +1753,7 @@ __PACKAGE__->status( add => 25290, iridium => 'D', 'Iridium 67', 'Decayed 2018-0
 __PACKAGE__->status( add => 25291, iridium => 'D', 'Iridium 68', 'Decayed 2018-06-06' );
 __PACKAGE__->status( add => 25319, iridium => '-', 'Iridium 69', 'Tumbling' );
 __PACKAGE__->status( add => 25320, iridium => '-', 'Iridium 71', 'Tumbling' );
-__PACKAGE__->status( add => 25342, iridium => '+', 'Iridium 70', '' );
+__PACKAGE__->status( add => 25342, iridium => 'S', 'Iridium 70', '' );
 __PACKAGE__->status( add => 25343, iridium => 'D', 'Iridium 72', 'Decayed 2018-05-14' );
 __PACKAGE__->status( add => 25344, iridium => '-', 'Iridium 73', 'Tumbling' );
 __PACKAGE__->status( add => 25345, iridium => 'D', 'Iridium 74', 'Decayed 2017-06-11' );
@@ -1768,7 +1768,7 @@ __PACKAGE__->status( add => 25471, iridium => 'D', 'Iridium 77', 'Decayed 2017-0
 __PACKAGE__->status( add => 25527, iridium => '-', 'Iridium 2', 'Tumbling' );
 __PACKAGE__->status( add => 25528, iridium => '-', 'Iridium 86', 'Tumbling' );
 __PACKAGE__->status( add => 25529, iridium => 'D', 'Iridium 85', 'Decayed 2000-12-30' );
-__PACKAGE__->status( add => 25530, iridium => 'S', 'Iridium 84', '' );
+__PACKAGE__->status( add => 25530, iridium => '-', 'Iridium 84', 'Tumbling' );
 __PACKAGE__->status( add => 25531, iridium => '+', 'Iridium 83', '' );
 __PACKAGE__->status( add => 25577, iridium => 'S', 'Iridium 20', '' );
 __PACKAGE__->status( add => 25578, iridium => 'S', 'Iridium 11', '' );
@@ -1783,10 +1783,10 @@ __PACKAGE__->status( add => 27450, iridium => 'S', 'Iridium 97', '' );
 __PACKAGE__->status( add => 27451, iridium => 'D', 'Iridium 98', 'Decayed 2018-08-24' );
 
 # Summary:
-# Operational [+]: 13
+# Operational [+]: 10
 #       Spare [S]: 12
-#    Tumbling [-]: 37
-#     Decayed [D]: 35
+#    Tumbling [-]: 38
+#     Decayed [D]: 37
 
 1;
 
